# minswap-py (v0.1.1)
<p align="center">
    <img src="https://img.shields.io/pypi/status/minswap-py?style=flat-square" />
    <img src="https://img.shields.io/pypi/dm/minswap-py?style=flat-square" />
    <img src="https://img.shields.io/pypi/l/minswap-py?style=flat-square"/>
    <img src="https://img.shields.io/pypi/v/minswap-py?style=flat-square"/>
    <a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</p>

`noobminswap` is a fork of `minswap-py, a tool to interact with [Minswap](https://minswap.org/).  The current version has feature parity with the minswap [blockfrost-adapter](https://github.com/minswap/blockfrost-adapter).

Documentation and additional features coming soon.

## Quickstart

In order to use this package:
1. Install with `pip install noobminswap`
2. Sign up for blockfrost and get an API key.
3. In your working directory, save a `.env` file. In this file, save your blockfrost API key as follows:
```bash
PROJECT_ID=YOUR_BLOCKFROST_ID
```

Once you do this, you can try out the code in the `examples` folder on the Github repository.
